/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 1.0
 */


using System;
using System.Collections;
using System.IO;

namespace TopCoder.File.Statistics.Matcher
{
    /// <summary>
    /// An implementation of <c>IFileMatcher</c> that will implicitely match any file.
    /// </summary>
    /// <remarks>
    /// No configuration is read. Naturally, the implementation is stateless and thread-safe.
    /// </remarks>
    public class AnyFileMatcher : IFileMatcher
    {
        /// <summary>
        /// Default constructor. Does nothing, as the implementation lacks state.
        /// </summary>
        public AnyFileMatcher()
        {
        }

        /// <summary>
        /// The contract constructor for instantiating <c>IFileMatcher</c> instances from configuration. No
        /// configuration is read in this implementation.
        /// </summary>
        /// <param name="nameSpace">The configuration manager namespace where the configuration resides.</param>
        /// <param name="prefix">The prefix to the configuration properties to parse.</param>
        /// <exception cref="ArgumentNullException">If <c>nameSpace</c> or <c>prefix</c> is null.</exception>
        /// <exception cref="ArgumentException">If <c>nameSpace</c>, when trimmed, is empty.</exception>
        /// <exception cref="ConfigurationException">If any config error occurs.</exception>
        public AnyFileMatcher(string nameSpace, string prefix)
        {
            Helper.CheckConfigData(nameSpace, prefix);
        }

        /// <summary>
        /// Performs file matching, which is simple here, every file is matched.
        /// </summary>
        /// <param name="file">The file to match.</param>
        /// <exception cref="ArgumentNullException">If <c>file</c> is null.</exception>
        /// <returns><c>true</c></returns>
        public bool Match(FileInfo file)
        {
            if (file == null)
            {
                throw new ArgumentNullException("file");
            }

            return true;
        }
    }
}