/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 1.0
 */


using System;
using System.IO;

namespace TopCoder.File.Statistics.Matcher
{
    /// <summary>
    /// An abstract implementation of <c>IFileMatcher</c> that lets subclasses concentrate on examining the file name.
    /// </summary>
    /// <remarks>
    /// No configuration is read by this class. The implementation is stateless and thread-safe. Subclasses may break
    /// either or both of these. Most will probably be able to parse a configuration and actually have a configuration
    /// of some kind.
    /// </remarks>
    public abstract class FileNameMatcher : IFileMatcher
    {
        /// <summary>
        /// Default constructor. Does nothing.
        /// </summary>
        protected FileNameMatcher()
        {
        }

        /// <summary>
        /// Extracts the file name and passes the call on to the specific name checking implementation of the subclass.
        /// </summary>
        /// <param name="file">The file to match.</param>
        /// <exception cref="ArgumentNullException">If <c>file</c> is null.</exception>
        /// <exception cref="FileMatchingException">Other error conditions.</exception>
        /// <returns><c>true</c> if the file name matches, <c>false</c> otherwise.</returns>
        public bool Match(FileInfo file)
        {
            if (file == null)
            {
                throw new ArgumentNullException("file");
            }

            return Match(file.FullName);
        }

        /// <summary>
        /// Template method to match a filename.
        /// </summary>
        /// <param name="fileName">Non-null file name.</param>
        /// <exception cref="FileMatchingException">Any error condition.</exception>
        /// <returns></returns>
        protected abstract bool Match(string fileName);
    }
}