/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 1.0
 */

using System;
using System.Reflection;
using NUnit.Framework;
using System.IO;
using System.Collections;

namespace TopCoder.File.Statistics.Matcher
{
    /// <summary>
    /// Tests the <c>ExtensionMatcher</c> class, by verifying a few test file names and different configurations.
    /// </summary>
    [TestFixture]
    public class TestExtensionMatcher : TestFileMatcher
    {
        /// <summary>
        /// A few file matchers used in testing, based on configuration and programmatical constructors.
        /// </summary>
        IFileMatcher[] matchers = new IFileMatcher[4];

        /// <summary>
        /// Publishes some information to base classes.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            type = typeof(ExtensionMatcher);
            instance = new ExtensionMatcher("java");
            matchers[0] = instance;
            IList list = new ArrayList();
            list.Add("java");
            list.Add("cs");
            matchers[1] = new ExtensionMatcher(list);
            matchers[2] = new ExtensionMatcher("TopCoder.File.Statistics", "1");
            matchers[3] = new ExtensionMatcher("TopCoder.File.Statistics", "2");
        }

        /// <summary>
        /// The list is present, but empty.
        /// </summary>
        [ExpectedException(typeof(ConfigurationException))]
        public void TestInvalidConfig1()
        {
            Constructor("TopCoder.File.Statistics", "3");
        }

        /// <summary>
        /// The list isn't present.
        /// </summary>
        [ExpectedException(typeof(ConfigurationException))]
        public void TestInvalidConfig2()
        {
            Constructor("TopCoder.File.Statistics", "4");
        }

        /// <summary>
        /// Tests matching of arbitrary <c>FileInfo</c> instances.
        /// </summary>
        [Test]
        public void TestMatch()
        {
            Assert.IsTrue(instance.Match(new FileInfo("Idontexist.java")),
                "Java file should match single-extension matcher.");
            Assert.IsFalse(instance.Match(new FileInfo("Idontexist.cs")),
                "C# file shouldn't match single-extension matcher.");
            Assert.IsFalse(instance.Match(new FileInfo("Idontexist")),
                "No extension file shouldn't match single-extension matcher.");

            for (int i = 1; i < 3; i++)
            {
                Assert.IsTrue(matchers[i].Match(new FileInfo("Idontexist.java")),
                    "Java file should match matcher " + i);

                // Check the ignore case behavior here
                Assert.IsTrue(matchers[i].Match(new FileInfo("Idontexist.CS")),
                    "C# file should match matcher " + i);
                Assert.IsFalse(matchers[i].Match(new FileInfo("Idontexist.jpeg")),
                    "JPEG file shouldn't match matcher " + i);
                Assert.IsFalse(matchers[i].Match(new FileInfo("Idontexist")),
                    "No extension file shouldn't match matcher " + i);
            }


            Assert.IsFalse(matchers[3].Match(new FileInfo("Idontexist.java")),
                    "Java file shouldn't match matcher 3");

            // Check the ignore case behavior here
            Assert.IsTrue(matchers[3].Match(new FileInfo("Idontexist.Cs")),
                "C# file should match matcher 3");
            Assert.IsFalse(matchers[3].Match(new FileInfo("Idontexist.jpeg")),
                "JPEG file shouldn't match matcher 3");
            Assert.IsTrue(matchers[3].Match(new FileInfo("Idontexist")),
                "No extension file should match matcher 3");
        }
    }
}