/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 1.0
 */

using System;
using System.Reflection;
using TopCoder.Util.ConfigurationManager;
using NUnit.Framework;
using System.IO;

namespace TopCoder.File.Statistics.Reporting
{
    /// <summary>
    /// Tests for <c>XmlStatsReporting</c> based on <c>TestAbstractStatsReporting</c>.
    /// </summary>
    [TestFixture]
    public class TestXmlStatsReporting : TestAbstractStatsReporting
    {
        /// <summary>
        /// The golden standard for the reports. One has to be careful, as absolute paths are hard to verify.
        /// </summary>
        private static readonly string[] reports = new string[]
            {
            @"<?xml version=""1.0"" encoding=""utf-16""?>
<report>
  <files>
    <file name=""sub\exe\test.exe"">
      <line>204</line>
    </file>
    <file name=""sub\TestFile1.cs"">
      <line>8</line>
    </file>
  </files>
  <directories>
    <directory name=""sub"">
      <line>212</line>
    </directory>
    <directory name=""sub\exe"">
      <line>204</line>
    </directory>
  </directories>
  <aliases>
    <alias name=""alias"">
      <line>212</line>
    </alias>
  </aliases>
  <overall>
    <line>212</line>
  </overall>
</report>",
            @"2048212204212212"};


        /// <summary>
        /// Sets the type value.
        /// </summary>
        [SetUp]
        public override void Setup()
        {
            type = typeof(XmlStatsReporting);
            base.Setup();
        }

        /// <summary>
        /// Tests report generation.
        /// </summary>
        public void TestGenerateReport()
        {
            // If you want to check both, you'll have to create a "gold standard" report with a specific absolute path
            for (int i = 0; i < 1; i++)
            {
                Assert.AreEqual(reports[i], instances[i].GenerateReport(), "Report deviating.");
            }
        }

        /// <summary>
        /// Prepares a report with a transform, from creating the instance to finishing it off.
        ///
        /// The stylesheet itself isn't very useful in this case.
        /// </summary>
        public void TestTransform()
        {
            instances[1] = (AbstractStatsReporting) Constructor(new FileInfo(@"..\..\test_files\default.xsl"));

            // One is reset, the other not, so we can make some comparisons
            instances[1].Reset(baseDir);

            AggregateFile(1, new FileInfo(@"..\..\test_files\sub\TestFile1.cs"));
            AggregateFile(1, new FileInfo(@"..\..\test_files\sub\exe\Test.exe"));

            // We "hijack" instance 1
            for (int i = 1; i < 2; i++)
            {
                Assert.AreEqual(reports[i], instances[i].GenerateReport(), "Report deviating.");
            }
        }
    }
}