/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 2.0b
 */


using System;
using System.IO;

namespace TopCoder.File.Statistics.Matcher
{
    /// <summary>
    /// An implementation of <c>IFileMatcher</c> that matches all binary files. <see cref="FileCategoryMatcher" /> for
    /// information on how this is determined.
    /// </summary>
    /// <remarks>
    /// No real configuration is read by this class, it always matches all text files. The implementation is stateless
    /// and thread-safe.
    /// </remarks>
    public class BinaryFileMatcher : FileCategoryMatcher
    {
        /// <summary>
        /// Default constructor. Does nothing.
        /// </summary>
        public BinaryFileMatcher()
        {
        }

        /// <summary>
        /// The contract constructor for creating <c>IFileMatcher</c> instances from the configuration manager. This is
        /// done by reading relevant simulated "sub-properties" under <c>prefix</c>.
        /// </summary>
        /// <remarks>
        /// Nothing is done in this constructor, just some basic verification of the parameters.
        /// </remarks>
        /// <param name="nameSpace">The namespace of the property.</param>
        /// <param name="prefix">The prefix to the property names.</param>
        /// <exception cref="ArgumentNullException">If <c>nameSpace</c> or <c>prefix</c> is null.</exception>
        /// <exception cref="ArgumentException">If <c>nameSpace</c>, when trimmed, is empty.</exception>
        /// <exception cref="ConfigurationException">If any config error occurs.</exception>
        public BinaryFileMatcher(string nameSpace, string prefix)
        {
            Helper.CheckConfigData(nameSpace, prefix);
        }

        /// <summary>
        /// Implementation of the abstract method in base class to match text files.
        /// </summary>
        /// <param name="isBinary">Parameter from base class for file category.</param>
        /// <exception cref="FileMatchingException">Any error condition.</exception>
        /// <returns><c>!isBinary</c>, that is, every non-binary (text) file is matched</returns>
        protected override bool Match(bool isBinary)
        {
            return isBinary;
        }
    }
}