/*
Copyright (c)2005, TopCoder, Inc. All rights reserved
Author Cucu
*/

using NUnit.Framework;
using TopCoder.File.Statistics;
using System.IO;
using TopCoder.File.Statistics.Matcher;

namespace TopCoder.File.Statistics.AccuracyTests.Matcher
{
    /// <summary>
    /// Accuracy tests for TextFileMatcher.
    /// </summary>
    [TestFixture]
    public class TextMatcherAccuracyTest
    {       
        /// <summary>
        /// TextFileMatcher used for testing
        /// </summary>
        private IFileMatcher matcher = new TextFileMatcher();

        /// <summary>
        /// Test the Match method against some text files to see that it matches them.
        /// </summary>
        [Test]
        public void TestMatch()
        {
            Assert.IsTrue(matcher.Match(new FileInfo (TestHelper.TXT_FILE)), 
                TestHelper.TXT_FILE + " must be considered as text file");            

            Assert.IsTrue(matcher.Match(new FileInfo (TestHelper.CS_FILE)), 
                TestHelper.CS_FILE + " must be considered as text file");
        }

        /// <summary>
        /// Test the Match method against some binary files to see that it doesn't matches them.
        /// </summary>
        [Test]
        public void TestNoMatch()
        {
            Assert.IsFalse(matcher.Match(new FileInfo (TestHelper.ZIP_FILE)), 
                TestHelper.ZIP_FILE + " must be considered as binary file");

            Assert.IsFalse(matcher.Match(new FileInfo (TestHelper.DLL_FILE)), 
                TestHelper.DLL_FILE + " must be considered as binary file");
        }
    }    
}