/*
Copyright (c)2005, TopCoder, Inc. All rights reserved
Author Cucu
*/
using TopCoder.File.Statistics.Matcher;
using TopCoder.File.Statistics.Processor.LineCounter;
using NUnit.Framework;
using TopCoder.File.Statistics;
using System.IO;

namespace TopCoder.File.Statistics.AccuracyTests.Processor.LineCounter
{
    /// <summary>
    /// Accuracy tests for TextLineCounter
    /// </summary>
    [TestFixture]
    public class TextLineCounterAccuracyTest
    {       
        /// <summary>
        /// Test the line count against some files.
        /// </summary>
        [Test]
        public void TestMatch()
        {
            IFileProcessor fp = new TextLineCounter("txt", new AnyFileMatcher());
            
            VerifyLineCount(fp, TestHelper.TXT_FILE, 2);
            VerifyLineCount(fp, TestHelper.LYRIC_TXT_FILE, 15);
            VerifyLineCount(fp, TestHelper.BIG_TXT_FILE, 21609);
        }

        /// <summary>
        /// Verifies that the line count is correct for a file
        /// </summary>
        /// <param name="fp">IFileProcessor that will process the file</param>
        /// <param name="filename">file whose text lines will be counted</param>
        /// <param name="expectedCount">expected number of lines</param>
        private void VerifyLineCount(IFileProcessor fp, string filename, int expectedCount) 
        {
            FileInfo file = new FileInfo (filename);
            Assert.AreEqual(expectedCount, fp.Process(file)[(Metric) fp.SupportedMetrics[0]], 
                " bad text line count for "  + filename);
        }
    }    
}