/*
Copyright (c)2005, TopCoder, Inc. All rights reserved
Author Cucu
*/
using NUnit.Framework;
using TopCoder.File.Statistics;


namespace TopCoder.File.Statistics.AccuracyTests
{

    /// <summary>
    /// Accuracy tests for StatsResult
    /// </summary>
    [TestFixture]
    public class StatsResultAccuracyTest
    {       
        /// <summary>
        /// Metric used for testing
        /// </summary>
        private Metric m1 =  new Metric("metric1", "displayName 1","descritpion 1");
        
        /// <summary>
        /// Metric used for testing
        /// </summary>
        private Metric m2 =  new Metric("metric2", "displayName 2","descritpion 2");
        
        /// <summary>
        /// Object to be tested.
        /// </summary>
        private StatsResult sr;

        /// <summary>
        /// Set up a stats result with two metrics
        /// </summary>
        [SetUp]
        public void SetUp() 
        {
            sr = new StatsResult();
            sr[m1] = 10;
            sr[m2] = 20;
        }

        /// <summary>
        /// Test getting metrics values with the indexer
        /// </summary>
        [Test]
        public void TestGetIndexer() 
        {
            Assert.AreEqual(10, sr[m1], "bad get/set indexer");
            Assert.AreEqual(20, sr[m2], "bad get/set indexer");
        }

        /// <summary>
        /// Test Metrics property
        /// </summary>
        [Test]
        public void TestMetrics() 
        {
            Assert.IsTrue(sr.Metrics.Contains(m1), "m1 not included in the metrics list");
            Assert.IsTrue(sr.Metrics.Contains(m2), "m2 not included in the metrics list");
        }

        /// <summary>
        /// Test using the copy constructor
        /// </summary>
        [Test]
        public void TestCopyConstructor() 
        {
            // Test copy constructor
            StatsResult sr2 = new StatsResult(sr);
            Assert.AreEqual(10, sr[m1], "copy constructor problem");
            Assert.AreEqual(20, sr[m2], "copy constructor problem");
        }

        /// <summary>
        /// Test the Aggregate method
        /// </summary>
        [Test]
        public void TestAggregate() 
        {
            StatsResult sr2 = new StatsResult();
            sr2[m1] = 100;
            sr.Aggregate(sr2);

            Assert.AreEqual(110, sr[m1], "aggregation problem");
            Assert.AreEqual(20, sr[m2], "aggregation  constructor problem");
        }

    }    
}