/*
 * $(#)ExtendedFileStatisticsTests.cs		Sep 6, 2005
 * 
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

using System;
using System.IO;
using NUnit.Framework;

using TopCoder.File.Statistics;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.File.Statistics.FailureTests {
	
	/// <summary>
    /// This test fixture contains the failure tests for <see cref="ExtendedFileStatistics"/> class.
    ///
    /// <author>MPhk</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
	public class ExtendedFileStatisticsTests {

	    /// <summary>
	    /// The the base path of the test files.
	    /// </summary>
	    private const string BASE_PATH = "../../test_files";
	
	    /// <summary>
	    /// The namespace for this test.
	    /// </summary>
	    private const string NAMESPACE = "TopCoder.File.Statistics.FailureTests";
	
	    /// <summary>
	    /// An ExtendedFileStatistics instance to test.
	    /// </summary>
	    private ExtendedFileStatistics fileStatistics = null;
	
	    /// <summary>
	    /// Creates an ExtendedFileStatistics instance.
	    ///
	    /// @throws Exception in case anything goes wrong
	    /// </summary>
	    [SetUp]
	    protected void SetUp() {
	        fileStatistics = new ExtendedFileStatistics();
	    }
	
	    /// <summary>
	    /// Checks whether the constructor - ExtendedFileStatistics(String) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestExtendedFileStatistics1() {
	        new ExtendedFileStatistics(null);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor - ExtendedFileStatistics(String) properly throws
	    /// ArgumentException for empty String argument.
	    ///
	    /// @throws Exception in case anything goes wrong
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestExtendedFileStatistics2() {
	        new ExtendedFileStatistics(" ");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor - ExtendedFileStatistics(String) properly throws
	    /// ConfigurationException for invalid configuration.
	    ///
	    /// @throws Exception in case anything goes wrong
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestExtendedFileStatistics3() {
	        const string CONFIG_FILE_1 = BASE_PATH + "/failuretests/invalid1.xml";
	        const string CONFIG_FILE_2 = BASE_PATH + "/failuretests/invalid2.xml";
	        // clear the namespace first
	        ConfigManager configManager = ConfigManager.GetInstance();
	        configManager.RemoveFile(CONFIG_FILE_1);
	        configManager.RemoveFile(CONFIG_FILE_2);
	        // load the configuration
	        configManager.LoadFile(CONFIG_FILE_1);
	
	        new ExtendedFileStatistics(NAMESPACE);
	        configManager.RemoveFile(NAMESPACE);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor - ExtendedFileStatistics(String) properly throws
	    /// ConfigurationException for invalid configuration.
	    ///
	    /// @throws Exception in case anything goes wrong
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestExtendedFileStatistics4() {
	        const string CONFIG_FILE_1 = BASE_PATH + "/failuretests/invalid1.xml";
	        const string CONFIG_FILE_2 = BASE_PATH + "/failuretests/invalid2.xml";
	        // clear the namespace first
	        ConfigManager configManager = ConfigManager.GetInstance();
	        configManager.RemoveFile(CONFIG_FILE_1);
	        configManager.RemoveFile(CONFIG_FILE_2);
	        // load the configuration
	        configManager.LoadFile(CONFIG_FILE_2);
	
	        new ExtendedFileStatistics(NAMESPACE);
	        configManager.RemoveFile(NAMESPACE);
	    }
	
	    /// <summary>
	    /// Checks whether the method addFileProcessor(String) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestAddFileProcessor() {
            fileStatistics.AddFileProcessor(null);
	    }
	
	    /// <summary>
	    /// Checks whether the method removeFileProcessor(String) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestRemoveFileProcessor1() {
            fileStatistics.RemoveFileProcessor(null);
	    }
	
	    /// <summary>
	    /// Checks whether the method removeFileProcessor(String) properly throws
	    /// ArgumentException for empty String argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestRemoveFileProcessor2() {
            fileStatistics.RemoveFileProcessor(" ");
	    }
	    
	    /// <summary>
	    /// Checks whether the method setReporting(StatsReporting) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestSetReporting() {
            fileStatistics.Reporting = null;
	    }
	
	    /// <summary>
	    /// Checks whether the method processFile(DirectoryInfo) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestProccessFile() {
            fileStatistics.ProcessFile(null);
	    }
	    
	    /// <summary>
	    /// Checks whether the method processDirectory(DirectoryInfo) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestProcessDirectory1() {
            fileStatistics.ProcessDirectory(null);
	    }
	
	    /// <summary>
	    /// Checks whether the method processDirectory(DirectoryInfo) properly throws
	    /// IOException for invalid argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestProcessDirectory2() {
	    	try {
            	fileStatistics.ProcessDirectory(new DirectoryInfo(BASE_PATH + "/inexistent_dir"));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
	
	    /// <summary>
	    /// Checks whether the method processDirectory(DirectoryInfo) properly throws
	    /// IOException for invalid argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestProcessDirectory3() {
	    	try {
            	fileStatistics.ProcessDirectory(new DirectoryInfo(BASE_PATH + "/valid.file"));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
	
	    /// <summary>
	    /// Checks whether the method processDirectory(DirectoryInfo, boolean) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestProcessDirectory4() {
            fileStatistics.ProcessDirectory(null, false);
	    }
	
	    /// <summary>
	    /// Checks whether the method processDirectory(DirectoryInfo) properly throws
	    /// IOException for invalid argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestProcessDirectory5() {
	    	try {
            	fileStatistics.ProcessDirectory(new DirectoryInfo(BASE_PATH + "/inexistent_dir"), false);
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
	
	    /// <summary>
	    /// Checks whether the method processDirectory(DirectoryInfo) properly throws
	    /// IOException for invalid argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestProcessDirectory6() {
	    	try {
            	fileStatistics.ProcessDirectory(new DirectoryInfo(BASE_PATH + "/valid.file"), false);
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
	
	    /// <summary>
	    /// Checks whether the method printReport(FileInfo) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestPrintReport1() {
            fileStatistics.PrintReport(null);
	    }
	
	    /// <summary>
	    /// Checks whether the method printReport(FileInfo) properly throws
	    /// IOException for invalid file argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestPrintReport2() {
	    	try {
	    		fileStatistics.PrintReport(new FileInfo(BASE_PATH));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
	}
}
