using System;
using System.Collections;
using System.IO;
using NUnit.Framework;
using TopCoder.File.Statistics.Matcher;
using TopCoder.File.Statistics.Processor;
using TopCoder.File.Statistics.Processor.LineCounter;
using TopCoder.File.Statistics.Reporting;

namespace TopCoder.File.Statistics.StressTests
{
	[TestFixture]
	[Ignore("You are slow!")]
	public class DirectoriesTests
	{
		private int levels = 4;

		private int childrenAtLevel = 4;

		private int filesInNode = 10;

		private string STANDARD_FILE_CONTENT = "....";

		ExtendedFileStatistics statistics;

		IFileMatcher matcher1;

		IFileProcessor processor1;

		IStatsReporting reporting1;

		private IList files = new ArrayList();
		private IList folders = new ArrayList();

		[SetUp]
		public void SetUp()
		{
		    files = new ArrayList();
		    folders = new ArrayList();
		    
			// create a file statistics instance
			statistics = new ExtendedFileStatistics();

			// create file matchers
			matcher1 = new AnyFileMatcher();

			// create file processors
			processor1 = new CStyleLineCounter("Text File", matcher1);

			// create stats reporting implementation
			reporting1 = new BasicStatsReporting();

			//assign the report object
			statistics.Reporting = reporting1;

			// manipulate file processors
			statistics.AddFileProcessor(processor1);

			StreamReader reader = new StreamReader(System.IO.File.OpenRead(@"..\..\test_files\stresstests\standard_file.txt"));
			STANDARD_FILE_CONTENT = reader.ReadToEnd();
			reader.Close();
			DirectoryInfo root = new DirectoryInfo(@"..\..\test_files\stressdir");
			folders.Add(root.FullName);
			generate(0, root);
		}

		[TearDown]
		public void TearDown()
		{
			for(int i = 0; i < files.Count; ++i)
			{
				string name = (string)files[i];
				FileInfo file = new FileInfo(name);
				file.Delete();
			}
			for(int i = folders.Count - 1; i >= 0; --i)
			{
				string name = (string)folders[i];
				DirectoryInfo dir = new DirectoryInfo(name);
				dir.Delete();
			}
		}

		private void generate(int levelNum, DirectoryInfo directory)
		{
			if (levelNum != 0)
			{
				for(int i = 0; i < filesInNode; ++i)
				{
					string filename = String.Format(@"{0}\{1}.txt", directory.FullName, i);
					FileStream file = System.IO.File.Create(filename);
					StreamWriter writer = new StreamWriter(file);
					writer.Write(STANDARD_FILE_CONTENT);
					writer.Close();
					files.Add(filename);
				}
			}
			if (levelNum < levels)
			{
				for(int i = 0; i < childrenAtLevel; ++i)
				{
					DirectoryInfo subDir = directory.CreateSubdirectory(String.Format("d{0}", i));
					folders.Add(subDir.FullName);
					generate(levelNum + 1, subDir);
				}
			}
		}

		/// <summary>
		/// Processes a hierarchy of files and folders that is deep and wide.
		/// The aim being to test the ProcessDirectory feature. And the intermediate
		/// data storage structures. A successful test will not throw a StackOverflowException
		/// </summary>
		public void testProcessLargeHierarchy()
		{
			// process directory
			DateTime start = DateTime.Now;
			statistics.ProcessDirectory(new DirectoryInfo(@"..\..\test_files\stressdir"), true);
			TimeSpan duration = DateTime.Now - start;
			Console.WriteLine("Processing a large hierarchy took {0} ms", duration.TotalMilliseconds);
		}

		/// <summary>
		/// Processes a hierarchy of files and folders that is deep and wide.
		/// The aim here is to test the report generation mechanism
		/// </summary>
		public void testReportOnLargeHierarchy()
		{
			// process directory
			statistics.ProcessDirectory(new DirectoryInfo(@"..\..\test_files\stressdir"), true);
			DateTime start = DateTime.Now;
			statistics.Reporting.GenerateReport();
			TimeSpan duration = DateTime.Now - start;
			Console.WriteLine("Reporting on a large hierarchy took {0} ms", duration.TotalMilliseconds);
		}
	}
}
